@@ -50,6 +50,7 @@
 #include "sound.h"
 #include "gaim.h"
 #include "gaim-socket.h"
+#include "gtklist.h"
 #if HAVE_SIGNAL_H
 #include <signal.h>
 #endif
@@ -74,6 +75,7 @@ GtkWidget *mainwindow = NULL;
 
 
 int opt_away = 0;
+int docklet_count = 0;
 char *opt_away_arg = NULL;
 char *opt_rcfile_arg = NULL;
 int opt_debug = 0;
@@ -274,7 +276,7 @@ static GList *combo_user_names()
 static void login_window_closed(GtkWidget *w, GdkEvent *ev, gpointer d)
 {
 	if(docklet_count) {
-#if _WIN32
+#ifdef _WIN32
 		wgaim_systray_minimize(mainwindow);
 #endif
 		gtk_widget_hide(mainwindow);
@@ -284,7 +286,6 @@ static void login_window_closed(GtkWidget *w, GdkEvent *ev, gpointer d)
 
 void show_login()
 {
-	GdkPixbuf *icon;
 	GtkWidget *image;
 	GtkWidget *vbox;
 	GtkWidget *button;
@@ -292,6 +293,7 @@ void show_login()
 	GtkWidget *label;
 	GtkWidget *vbox2;
 	GList *tmp;
+	char *filename;
 
 	/* Do we already have a main window opened? If so, bring it back, baby... ribs... yeah */
 	if (mainwindow) {
@@ -303,24 +305,19 @@ void show_login()
 
 	gtk_window_set_role(GTK_WINDOW(mainwindow), "login");
 	gtk_window_set_resizable(GTK_WINDOW(mainwindow), FALSE);
-	gtk_window_set_title(GTK_WINDOW(mainwindow), _("Gaim - Login"));
+	gtk_window_set_title(GTK_WINDOW(mainwindow), _("Login"));
 	gtk_widget_realize(mainwindow);
 	gdk_window_set_group(mainwindow->window, mainwindow->window);
 	gtk_container_set_border_width(GTK_CONTAINER(mainwindow), 5);
 	g_signal_connect(G_OBJECT(mainwindow), "delete_event",
 					 G_CALLBACK(login_window_closed), mainwindow);
 
-
-	icon = gaim_pixbuf(NULL, "gaim.png");
-	if (icon) {
-			gtk_window_set_icon(GTK_WINDOW(mainwindow), icon);
-			gdk_pixbuf_unref(icon);
-	}
-
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(mainwindow), vbox);
 
-	image = gaim_pixmap(NULL, "logo.png");
+	filename = g_build_filename(DATADIR, "pixmaps", "gaim", "logo.png", NULL);
+	image = gtk_image_new_from_file(filename);
+	g_free(filename);
 	gtk_box_pack_start(GTK_BOX(vbox), image, FALSE, FALSE, 0);
 
 	vbox2 = gtk_vbox_new(FALSE, 0);
@@ -383,11 +380,6 @@ void show_login()
 	g_signal_connect(G_OBJECT(button), "button-press-event", G_CALLBACK(domiddleclick), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 
-#ifdef _WIN32
-	/* Register newly created window with systray module */
-	wgaim_created_loginwin(GTK_WIDGET(mainwindow));
-#endif
-
 	/* Now grab the focus that we need */
 	if (gaim_accounts) {
 		struct gaim_account *account = gaim_accounts->data;
@@ -435,7 +427,7 @@ void sighandler(int sig)
 			"they can help you.\n");
 #else
 		fprintf(stderr, "Oh no!  Segmentation fault!\n");
-		g_on_error_query (g_get_prgname());
+		/*g_on_error_query (g_get_prgname());*/
 		exit(1);
 #endif
 		abort();
@@ -468,36 +460,53 @@ static gboolean socket_readable(GIOChannel *source, GIOCondition cond, gpointer
 	guint32 len;
 	guchar *data;
 	guint32 x;
+	GError *error;
 
 	debug_printf("Core says: ");
-	g_io_channel_read(source, &type, sizeof(type), &x);
+	g_io_channel_read_chars(source, &type, sizeof(type), &x, &error);
+	if(error)
+		g_error_free(error);
 	if (x == 0) {
 		debug_printf("CORE IS GONE!\n");
-		g_io_channel_close(source);
+		g_io_channel_shutdown(source, TRUE, &error);
+		if(error)
+			g_free(error);
 		return FALSE;
 	}
 	debug_printf("%d ", type);
-	g_io_channel_read(source, &subtype, sizeof(subtype), &x);
+	g_io_channel_read_chars(source, &subtype, sizeof(subtype), &x, &error);
+	if(error)
+		g_error_free(error);
 	if (x == 0) {
 		debug_printf("CORE IS GONE!\n");
-		g_io_channel_close(source);
+		g_io_channel_shutdown(source, TRUE, &error);
+		if(error)
+			g_error_free(error);
 		return FALSE;
 	}
 	debug_printf("%d ", subtype);
-	g_io_channel_read(source, (guchar *)&len, sizeof(len), &x);
+	g_io_channel_read_chars(source, (guchar *)&len, sizeof(len), &x, &error);
+	if(error)
+		g_error_free(error);
 	if (x == 0) {
 		debug_printf("CORE IS GONE!\n");
-		g_io_channel_close(source);
+		g_io_channel_shutdown(source, TRUE, &error);
+		if(error)
+			g_error_free(error);
 		return FALSE;
 	}
 	debug_printf("(%d bytes)\n", len);
 
 	data = g_malloc(len);
-	g_io_channel_read(source, data, len, &x);
+	g_io_channel_read_chars(source, data, len, &x, &error);
+	if(error)
+		g_error_free(error);
 	if (x != len) {
 		debug_printf("CORE IS GONE! (read %d/%d bytes)\n", x, len);
 		g_free(data);
-		g_io_channel_close(source);
+		g_io_channel_shutdown(source, TRUE, &error);
+		if(error)
+			g_error_free(error);
 		return FALSE;
 	}
 
@@ -516,6 +525,7 @@ static int ui_main()
 	GdkPixbuf *icon = NULL;
 	char *icon_path;
 #endif
+
 	if (current_smiley_theme == NULL) {
 		smiley_theme_probe();
 		if (smiley_themes) {
@@ -524,10 +534,6 @@ static int ui_main()
 		}
 	}
 
-	/* Set the UI operation structures. */
-	gaim_set_win_ui_ops(gaim_get_gtk_window_ui_ops());
-	gaim_set_xfer_ui_ops(gaim_get_gtk_xfer_ui_ops());
-
 	setup_stock();
 
 #ifndef _WIN32
@@ -539,8 +545,9 @@ static int ui_main()
 		icons = g_list_append(icons,icon);
 		gtk_window_set_default_icon_list(icons);
 		g_object_unref(G_OBJECT(icon));
+		g_list_free(icons);
 	} else {
-		debug_printf("Failed to load icon from %s" G_DIR_SEPARATOR_S "pixmaps" G_DIR_SEPARATOR_S "gaim.png\n",DATADIR);
+		debug_printf("Failed to load default window icon!\n");
 	}
 
 	g_snprintf(name, sizeof(name), "%s" G_DIR_SEPARATOR_S "gaim_%s.%d", g_get_tmp_dir(), g_get_user_name(), gaim_session);
@@ -551,6 +558,7 @@ static int ui_main()
 	channel = g_io_channel_unix_new(UI_fd);
 	g_io_add_watch(channel, G_IO_IN | G_IO_HUP | G_IO_ERR, socket_readable, NULL);
 #endif
+
 	return 0;
 }
 
@@ -860,6 +868,11 @@ int main(int argc, char *argv[])
 	wgaim_init();
 #endif
 
+	/* Set the UI operation structures. */
+	gaim_set_win_ui_ops(gaim_get_gtk_window_ui_ops());
+	gaim_set_xfer_ui_ops(gaim_get_gtk_xfer_ui_ops());
+	gaim_set_blist_ui_ops(gaim_get_gtk_blist_ui_ops());
+
 	load_prefs();
 	core_main();
 	ui_main();
