@@ -1,6 +1,6 @@
 /*
  * gaim - Gadu-Gadu Protocol Plugin
- * $Id: gg.c,v 1.44 2003/02/24 00:29:52 faceprint Exp $
+ * $Id: gg.c,v 1.54 2003/03/31 07:19:39 seanegan Exp $
  *
  * Copyright (C) 2001 Arkadiusz Mikiewicz <misiek@pld.ORG.PL>
  * 
@@ -54,11 +54,6 @@
 #include "win32dep.h"
 #endif
 
-#include "pixmaps/protocols/gg/gg_suncloud.xpm"
-#include "pixmaps/protocols/gg/gg_sunred.xpm"
-#include "pixmaps/protocols/gg/gg_sunwhitered.xpm"
-#include "pixmaps/protocols/gg/gg_sunyellow.xpm"
-
 #define USEROPT_NICK 0
 
 #define AGG_BUF_LEN 1024
@@ -90,7 +85,6 @@
 
 /* for win32 compatability */
 G_MODULE_IMPORT GSList *connections;
-G_MODULE_IMPORT GSList *groups;
 
 struct agg_data {
 	struct gg_session *sess;
@@ -122,10 +116,7 @@ static gboolean invalid_uin(const char *uin)
 
 static gint args_compare(gconstpointer a, gconstpointer b)
 {
-	gchar *arg_a = (gchar *)a;
-	gchar *arg_b = (gchar *)b;
-
-	return g_strcasecmp(arg_a, arg_b);
+	return g_ascii_strcasecmp((const gchar *)a,(const gchar *)b);
 }
 
 static gboolean allowed_uin(struct gaim_connection *gc, char *uin)
@@ -200,27 +191,27 @@ static void agg_set_away(struct gaim_connection *gc, char *state, char *msg)
 		gc->away = NULL;
 	}
 
-	if (!g_strcasecmp(state, AGG_STATUS_AVAIL))
+	if (!gaim_utf8_strcasecmp(state, AGG_STATUS_AVAIL))
 		status = GG_STATUS_AVAIL;
-	else if (!g_strcasecmp(state, AGG_STATUS_AVAIL_FRIENDS)) {
+	else if (!gaim_utf8_strcasecmp(state, AGG_STATUS_AVAIL_FRIENDS)) {
 		status = GG_STATUS_AVAIL | GG_STATUS_FRIENDS_MASK;
 		gc->away = g_strdup("");
-	} else if (!g_strcasecmp(state, AGG_STATUS_BUSY)) {
+	} else if (!gaim_utf8_strcasecmp(state, AGG_STATUS_BUSY)) {
 		status = GG_STATUS_BUSY;
 		gc->away = g_strdup("");
-	} else if (!g_strcasecmp(state, AGG_STATUS_BUSY_FRIENDS)) {
+	} else if (!gaim_utf8_strcasecmp(state, AGG_STATUS_BUSY_FRIENDS)) {
 		status =  GG_STATUS_BUSY | GG_STATUS_FRIENDS_MASK;
 		gc->away = g_strdup("");
-	} else if (!g_strcasecmp(state, AGG_STATUS_INVISIBLE)) {
+	} else if (!gaim_utf8_strcasecmp(state, AGG_STATUS_INVISIBLE)) {
 		status = GG_STATUS_INVISIBLE;
 		gc->away = g_strdup("");
-	} else if (!g_strcasecmp(state, AGG_STATUS_INVISIBLE_FRIENDS)) {
+	} else if (!gaim_utf8_strcasecmp(state, AGG_STATUS_INVISIBLE_FRIENDS)) {
 		status = GG_STATUS_INVISIBLE | GG_STATUS_FRIENDS_MASK;
 		gc->away = g_strdup("");
-	} else if (!g_strcasecmp(state, AGG_STATUS_NOT_AVAIL)) {
+	} else if (!gaim_utf8_strcasecmp(state, AGG_STATUS_NOT_AVAIL)) {
 		status = GG_STATUS_NOT_AVAIL;
 		gc->away = g_strdup("");
-	} else if (!g_strcasecmp(state, GAIM_AWAY_CUSTOM)) {
+	} else if (!gaim_utf8_strcasecmp(state, GAIM_AWAY_CUSTOM)) {
 		if (msg) {
 			status = GG_STATUS_BUSY;
 			gc->away = g_strdup("");
@@ -278,7 +269,7 @@ static GList *agg_buddy_menu(struct gaim_connection *gc, char *who)
 {
 	GList *m = NULL;
 	struct proto_buddy_menu *pbm;
-	struct buddy *b = find_buddy(gc->account, who);
+	struct buddy *b = gaim_find_buddy(gc->account, who);
 	static char buf[AGG_BUF_LEN];
 
 	if (!b) {
@@ -370,7 +361,7 @@ static void main_callback(gpointer data, gint source, GaimInputCondition cond)
 
 				g_snprintf(user, sizeof(user), "%lu", n->uin);
 				serv_got_update(gc, user, (status == UC_UNAVAILABLE) ? 0 : 1, 0, 0, 0,
-						status, 0);
+						status);
 				n++;
 			}
 		}
@@ -396,7 +387,7 @@ static void main_callback(gpointer data, gint source, GaimInputCondition cond)
 
 			g_snprintf(user, sizeof(user), "%lu", e->event.status.uin);
 			serv_got_update(gc, user, (status == UC_UNAVAILABLE) ? 0 : 1, 0, 0, 0,
-					status, 0);
+					status);
 		}
 		break;
 	case GG_EVENT_ACK:
@@ -470,13 +461,13 @@ void login_callback(gpointer data, gint source, GaimInputCondition cond)
 		{
 			struct in_addr ip;
 			char buf[256];
-			
+
 			/* Remove watch on initial socket - now that we have ip and port of login server */
 			gaim_input_remove(gc->inpa);
 
 			ip.s_addr = gd->sess->server_ip;
-			
-			if (proxy_connect(inet_ntoa(ip), gd->sess->port, login_callback, gc) < 0) {
+
+			if (proxy_connect(gc->account, inet_ntoa(ip), gd->sess->port, login_callback, gc) < 0) {
 				g_snprintf(buf, sizeof(buf), _("Connect to %s failed"), inet_ntoa(ip));
 				hide_login_progress(gc, buf);
 				signoff(gc);
@@ -572,7 +563,7 @@ static void agg_login(struct gaim_account *account)
 	gd->sess->state = GG_STATE_CONNECTING;
 	gd->sess->check = GG_CHECK_WRITE;
 	gd->sess->async = 1;
-	if (proxy_connect(GG_APPMSG_HOST, GG_APPMSG_PORT, login_callback, gc) < 0) {
+	if (proxy_connect(account, GG_APPMSG_HOST, GG_APPMSG_PORT, login_callback, gc) < 0) {
 		g_snprintf(buf, sizeof(buf), _("Connect to %s failed"), GG_APPMSG_HOST);
 		hide_login_progress(gc, buf);
 		signoff(gc);
@@ -798,7 +789,9 @@ static void import_buddies_server_results(struct gaim_connection *gc, gchar *web
 		}
 
 		debug_printf("import_buddies_server_results: uin: %s\n", name);
-		if (!find_buddy(gc->account, name)) {
+		if (!gaim_find_buddy(gc->account, name)) {
+			struct buddy *b;
+			struct group *g;
 			/* Default group if none specified on server */
 			gchar *group = g_strdup("Gadu-Gadu");
 			if (strlen(data_tbl[5])) {
@@ -810,7 +803,12 @@ static void import_buddies_server_results(struct gaim_connection *gc, gchar *web
 				g_strfreev(group_tbl);
 			}
 			/* Add Buddy to our userlist */
-			add_buddy(gc->account, group, name, strlen(show) ? show : name);
+			if (!(g = gaim_find_group(group))) {
+				g = gaim_group_new(group);
+				gaim_blist_add_group(g, NULL);
+			}
+			b = gaim_buddy_new(gc->account, name, strlen(show) ? show : NULL);
+			gaim_blist_add_buddy(b,g,NULL);
 			gaim_blist_save();
 			g_free(group);
 		}
@@ -988,7 +986,7 @@ static void import_buddies_server(struct gaim_connection *gc)
 	g_free(u);
 	g_free(p);
 
-	if (proxy_connect(GG_PUBDIR_HOST, GG_PUBDIR_PORT, http_req_callback, hi) < 0) {
+	if (proxy_connect(gc->account, GG_PUBDIR_HOST, GG_PUBDIR_PORT, http_req_callback, hi) < 0) {
 		do_error_dialog(_("Unable to import Gadu-Gadu buddy list"), 
 				_("Gaim was unable to connect to the Gadu-Gadu buddy list "
 				  "server.  Please try again later."), GAIM_ERROR);
@@ -1005,7 +1003,7 @@ static void export_buddies_server(struct gaim_connection *gc)
 	gchar *u = gg_urlencode(gc->username);
 	gchar *p = gg_urlencode(gc->password);
 
-	GSList *gr = groups;
+	GaimBlistNode *gnode, *bnode;
 
 	he->gc = gc;
 	he->type = AGG_HTTP_USERLIST_EXPORT;
@@ -1016,19 +1014,23 @@ static void export_buddies_server(struct gaim_connection *gc)
 	g_free(u);
 	g_free(p);
 
-	while (gr) {
-		struct group *g = gr->data;
-		GSList *m = g->members;
+	for(gnode = gaim_get_blist()->root; gnode; gnode = gnode->next) {
+		struct group *g = (struct group *)gnode;
 		int num_added=0;
-		while (m) {
-			struct buddy *b = m->data;
+		if(!GAIM_BLIST_NODE_IS_GROUP(gnode))
+			continue;
+		for(bnode = gnode->child; bnode; bnode = bnode->next) {
+			struct buddy *b = (struct buddy *)bnode;
+
+			if(!GAIM_BLIST_NODE_IS_BUDDY(bnode))
+				continue;
 
 			if(b->account == gc->account) {
 				gchar *newdata;
 				/* GG Number */
 				gchar *name = gg_urlencode(b->name);
 				/* GG Pseudo */
-				gchar *show = gg_urlencode(b->alias[0] ? b->alias : b->name);
+				gchar *show = gg_urlencode(b->alias ? b->alias : b->name);
 				/* Group Name */
 				gchar *gname = gg_urlencode(g->name);
 
@@ -1050,12 +1052,10 @@ static void export_buddies_server(struct gaim_connection *gc)
 				g_free(show);
 				g_free(name);
 			}
-			m = g_slist_next(m);
 		}
-		gr = g_slist_next(gr);
 	}
 
-	if (proxy_connect(GG_PUBDIR_HOST, GG_PUBDIR_PORT, http_req_callback, he) < 0) {
+	if (proxy_connect(gc->account, GG_PUBDIR_HOST, GG_PUBDIR_PORT, http_req_callback, he) < 0) {
 		do_error_dialog(_("Couldn't export buddy list"), 
 				_("Gaim was unable to connect to the buddy list server.  "
 				  "Please try again later."), GAIM_ERROR);
@@ -1077,7 +1077,7 @@ static void delete_buddies_server(struct gaim_connection *gc)
 	he->host = GG_PUBDIR_HOST;
 	he->request = g_strdup_printf("FmNum=%s&Pass=%s&Delete=1", u, p);
 
-	if (proxy_connect(GG_PUBDIR_HOST, GG_PUBDIR_PORT, http_req_callback, he) < 0) {
+	if (proxy_connect(gc->account, GG_PUBDIR_HOST, GG_PUBDIR_PORT, http_req_callback, he) < 0) {
 		do_error_dialog(_("Unable to delete Gadu-Gadu buddy list"), 
 				_("Gaim was unable to connect to the buddy list server.  "
 				  "Please try again later."), GAIM_ERROR);
@@ -1125,7 +1125,7 @@ static void agg_dir_search(struct gaim_connection *gc, const char *first, const
 		g_free(enew_city);
 	}
 
-	if (proxy_connect(GG_PUBDIR_HOST, GG_PUBDIR_PORT, http_req_callback, srch) < 0) {
+	if (proxy_connect(gc->account, GG_PUBDIR_HOST, GG_PUBDIR_PORT, http_req_callback, srch) < 0) {
 		do_error_dialog(_("Unable to access directory"), 
 				_("Gaim was unable to search the Directory because it "
 				  "was unable to connect to the directory server.  Please try "
@@ -1158,7 +1158,7 @@ static void agg_change_passwd(struct gaim_connection *gc, const char *old, const
 	g_free(enew);
 	g_free(eold);
 
-	if (proxy_connect(GG_REGISTER_HOST, GG_REGISTER_PORT, http_req_callback, hpass) < 0) {
+	if (proxy_connect(gc->account, GG_REGISTER_HOST, GG_REGISTER_PORT, http_req_callback, hpass) < 0) {
 	       	do_error_dialog(_("Unable to change Gadu-Gadu password"), 
 				_("Gaim was unable to change your password due to an error connecting "
 				  "to the Gadu-Gadu server.  Please try again later."), GAIM_ERROR);
@@ -1233,7 +1233,7 @@ static void agg_get_info(struct gaim_connection *gc, char *who)
 	} else
 		srch->request = g_strdup_printf("Mode=3&UserId=%s", who);
 
-	if (proxy_connect(GG_PUBDIR_HOST, GG_PUBDIR_PORT, http_req_callback, srch) < 0) {
+	if (proxy_connect(gc->account, GG_PUBDIR_HOST, GG_PUBDIR_PORT, http_req_callback, srch) < 0) {
 		do_error_dialog(_("Unable to access user profile."), 
 				_("Gaim was unable to access this user's profile due to an error "
 				  "connecting to the directory server.  Please try again later."), GAIM_ERROR);
@@ -1243,23 +1243,30 @@ static void agg_get_info(struct gaim_connection *gc, char *who)
 	}
 }
 
-static char **agg_list_icon(int uc)
+static const char *agg_list_icon(struct gaim_account *a, struct buddy *b)
 {
-	guint status;
-	if (uc == UC_UNAVAILABLE)
-		return (char **)gg_sunred_xpm;
-	status = uc >> 5;
-	/* Drop all masks */
-	status &= ~(GG_STATUS_FRIENDS_MASK);
-	if (status == GG_STATUS_AVAIL)
-		return (char **)gg_sunyellow_xpm;
-	if (status == GG_STATUS_BUSY)
-		return (char **)gg_suncloud_xpm;
-	if (status == GG_STATUS_INVISIBLE)
-		return (char **)gg_sunwhitered_xpm;
-	return (char **)gg_sunyellow_xpm;
+	return "gadu-gadu";
 }
 
+static void agg_list_emblems(struct buddy *b, char **se, char **sw, char **nw, char **ne)
+{
+	int status;
+	if (b->present == 0)
+		*se = "offline";
+	else if (b->uc == UC_UNAVAILABLE)
+		*se = "away";
+	else {
+		status = b->uc >> 5;
+		/* Drop all masks */
+		status &= ~(GG_STATUS_FRIENDS_MASK);
+		if (status == GG_STATUS_BUSY)
+			*se = "busy";
+		else if (status == GG_STATUS_INVISIBLE)
+			*se = "invisiible";
+	}
+}
+
+
 static void agg_set_permit_deny_dummy(struct gaim_connection *gc)
 {
 	/* It's implemented on client side because GG server doesn't support this */
@@ -1279,6 +1286,7 @@ G_MODULE_EXPORT void gg_init(struct prpl *ret)
 	ret->options = 0;
 	ret->name = g_strdup("Gadu-Gadu");
 	ret->list_icon = agg_list_icon;
+	ret->list_emblems = agg_list_emblems;
 	ret->away_states = agg_away_states;
 	ret->actions = agg_actions;
 	ret->buddy_menu = agg_buddy_menu;
