@@ -20,10 +20,13 @@
  */
 
 #include "gaim.h"
+#include "gtkutils.h"
 #include "prpl.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <string.h>
+#include <errno.h>
 
 #ifdef _WIN32
 #include "win32dep.h"
@@ -46,14 +49,14 @@ struct _prompt {
 	void *data;
 };
 
-struct prpl *find_prpl(int prot)
+struct prpl *find_prpl(GaimProtocol type)
 {
 	GSList *e = protocols;
 	struct prpl *r;
 
 	while (e) {
 		r = (struct prpl *)e->data;
-		if (r->protocol == prot)
+		if (r->protocol == type)
 			return r;
 		e = e->next;
 	}
@@ -101,7 +104,7 @@ void load_protocol(proto_init pi)
 				_("Gaim has loaded the ICQ plugin.  This plugin has been deprecated. "
 				  "As such, it was probably not compiled from the same version of the "
 				  "source as this application was, and cannot be guaranteed to work.  "
-				  "It is reccomended that you use the AIM/ICQ protocol to connect to ICQ"),
+				  "It is recommended that you use the AIM/ICQ protocol to connect to ICQ"),
 				GAIM_WARNING);
 	pi(p);
 	protocols = g_slist_insert_sorted(protocols, p, (GCompareFunc)proto_compare);
@@ -111,9 +114,22 @@ void load_protocol(proto_init pi)
 void unload_protocol(struct prpl *p)
 {
 	GList *c;
+	struct proto_user_split *pus;
 	struct proto_user_opt *puo;
 	if (p->name)
 		g_free(p->name);
+
+	c = p->user_splits;
+	while (c) {
+		pus = c->data;
+		g_free(pus->label);
+		g_free(pus->def);
+		g_free(pus);
+		c = c->next;
+	}
+	g_list_free(p->user_splits);
+	p->user_splits = NULL;
+
 	c = p->user_opts;
 	while (c) {
 		puo = c->data;
@@ -133,20 +149,34 @@ static void des_win(GtkWidget *a, GtkWidget *b)
 	gtk_widget_destroy(b);
 }
 
-static void rem_win(GtkWidget *a, GtkWidget *b)
-{
-	void *d = gtk_object_get_user_data(GTK_OBJECT(a));
-	if (d)
-		gtk_signal_disconnect_by_data(GTK_OBJECT(b), d);
-	gtk_widget_destroy(b);
-}
+static GSList *do_ask_dialogs = NULL;
 
 struct doaskstruct {
+	GtkWidget *dialog;
+	GModule *handle;
 	void (*yesfunc)(gpointer);
 	void (*nofunc)(gpointer);
 	gpointer data;
 };
 
+void do_ask_cancel_by_handle(GModule *handle)
+{
+	GSList *d = do_ask_dialogs;
+
+	debug_printf("%d dialogs to search\n", g_slist_length(d));
+
+	while (d) {
+		struct doaskstruct *doask = d->data;
+
+		d = d->next;
+
+		if (doask->handle == handle) {
+			debug_printf("removing dialog, %d remain\n", g_slist_length(d));
+			gtk_dialog_response(GTK_DIALOG(doask->dialog), GTK_RESPONSE_NONE);
+		}
+	}
+}
+
 static void do_ask_callback(GtkDialog *d, gint resp, struct doaskstruct *doask)
 {
 	switch (resp) 
@@ -155,12 +185,12 @@ static void do_ask_callback(GtkDialog *d, gint resp, struct doaskstruct *doask)
 			if (doask->yesfunc)
 				doask->yesfunc(doask->data);
 			break;
-		case GTK_RESPONSE_NO:
-		case GTK_RESPONSE_DELETE_EVENT:
+		default:
 			if (doask->nofunc)
 				doask->nofunc(doask->data);
 			break;
 		}
+	do_ask_dialogs = g_slist_remove(do_ask_dialogs, doask);
 	g_free(doask);
 	gtk_widget_destroy(GTK_WIDGET(d));
 }
@@ -170,7 +200,7 @@ static void do_ask_callback(GtkDialog *d, gint resp, struct doaskstruct *doask)
                                    if (!strcmp(r,notext))  \
                                            notext = l;     
 
-void do_ask_dialog(const char *prim, const char *sec, void *data, char *yestext, void *doit, char *notext, void *dont)
+void do_ask_dialog(const char *prim, const char *sec, void *data, char *yestext, void *doit, char *notext, void *dont, GModule *handle, gboolean modal)
 {
 	GtkWidget *window;
 	GtkWidget *hbox;
@@ -180,10 +210,6 @@ void do_ask_dialog(const char *prim, const char *sec, void *data, char *yestext,
 	GtkWidget *img = gtk_image_new_from_file(filename);
 	struct doaskstruct *doask = g_new0(struct doaskstruct, 1);
 
-	doask->yesfunc = doit;
-	doask->nofunc  = dont;
-	doask->data    = data;
-
 	g_free(filename);
 	gtk_misc_set_alignment(GTK_MISC(img), 0, 0);
 
@@ -199,10 +225,15 @@ void do_ask_dialog(const char *prim, const char *sec, void *data, char *yestext,
 	STOCK_ITEMIZE("Yes", GTK_STOCK_YES);
 	STOCK_ITEMIZE("No", GTK_STOCK_NO);
 
-	window = gtk_dialog_new_with_buttons("", NULL, GTK_DIALOG_MODAL, notext, GTK_RESPONSE_NO, yestext, GTK_RESPONSE_YES, NULL);
+	window = gtk_dialog_new_with_buttons("", NULL, 0, notext, GTK_RESPONSE_NO, yestext, GTK_RESPONSE_YES, NULL);
+
+	if (modal) {
+		gtk_window_set_modal(GTK_WINDOW(window), TRUE);
+	}
+
 	gtk_dialog_set_default_response (GTK_DIALOG(window), GTK_RESPONSE_YES);
 	g_signal_connect(G_OBJECT(window), "response", G_CALLBACK(do_ask_callback), doask);
-	
+
 	gtk_container_set_border_width (GTK_CONTAINER(window), 6);
 	gtk_window_set_resizable(GTK_WINDOW(window), FALSE);
 	gtk_dialog_set_has_separator(GTK_DIALOG(window), FALSE);
@@ -219,7 +250,14 @@ void do_ask_dialog(const char *prim, const char *sec, void *data, char *yestext,
 	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	
+
+	doask->dialog  = window;
+	doask->handle  = handle;
+	doask->yesfunc = doit;
+	doask->nofunc  = dont;
+	doask->data    = data;
+	do_ask_dialogs = g_slist_append(do_ask_dialogs, doask);
+
 	gtk_widget_show_all(window);
 }
 
@@ -255,10 +293,10 @@ void do_prompt_dialog(const char *text, const char *def, void *data, void *doit,
 
 	GAIM_DIALOG(window);
 	p->window = window;
-	gtk_window_set_wmclass(GTK_WINDOW(window), "prompt", "Gaim");
-	gtk_window_set_policy(GTK_WINDOW(window), FALSE, TRUE, TRUE);
+	gtk_window_set_role(GTK_WINDOW(window), "prompt");
+	gtk_window_set_resizable(GTK_WINDOW(window), TRUE);
 	gtk_window_set_title(GTK_WINDOW(window), _("Gaim - Prompt"));
-	gtk_signal_connect(GTK_OBJECT(window), "destroy", GTK_SIGNAL_FUNC(des_prompt), p);
+	g_signal_connect(GTK_OBJECT(window), "destroy", G_CALLBACK(des_prompt), p);
 	gtk_widget_realize(window);
 
 	vbox = gtk_vbox_new(FALSE, 5);
@@ -275,27 +313,27 @@ void do_prompt_dialog(const char *text, const char *def, void *data, void *doit,
 	gtk_box_pack_start(GTK_BOX(vbox), entry, FALSE, FALSE, 0);
 	if (def)
 		gtk_entry_set_text(GTK_ENTRY(entry), def);
-	gtk_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(act_prompt), p);
+	g_signal_connect(GTK_OBJECT(entry), "activate", G_CALLBACK(act_prompt), p);
 	p->entry = entry;
 
 	hbox = gtk_hbox_new(FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-	button = picture_button(window, _("Cancel"), cancel_xpm);
-	gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(des_win), window);
-
 	button = picture_button(window, _("Accept"), ok_xpm);
 	gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(act_prompt), p);
+	g_signal_connect(GTK_OBJECT(button), "clicked", G_CALLBACK(act_prompt), p);
+
+	button = picture_button(window, _("Cancel"), cancel_xpm);
+	gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+	g_signal_connect(GTK_OBJECT(button), "clicked", G_CALLBACK(des_win), window);
 
 	gtk_widget_show_all(window);
 }
 
-static void proto_act(GtkObject *obj, struct gaim_connection *gc)
+static void proto_act(GtkObject *obj, struct proto_actions_menu *pam)
 {
-	char *act = gtk_object_get_user_data(obj);
-	gc->prpl->do_action(gc, act);
+	if (pam->callback && pam->gc)
+		pam->callback(pam->gc);
 }
 
 void do_proto_menu()
@@ -304,6 +342,7 @@ void do_proto_menu()
 	GtkWidget *submenu;
 	GList *l;
 	GSList *c = connections;
+	struct proto_actions_menu *pam;
 	struct gaim_connection *gc = NULL;
 	int count = 0;
 	char buf[256];
@@ -311,95 +350,92 @@ void do_proto_menu()
 	if (!protomenu)
 		return;
 
-	l = gtk_container_children(GTK_CONTAINER(protomenu));
+	l = gtk_container_get_children(GTK_CONTAINER(protomenu));
 	while (l) {
-		gtk_container_remove(GTK_CONTAINER(protomenu), GTK_WIDGET(l->data));
+		menuitem = l->data;
+		pam = g_object_get_data(G_OBJECT(menuitem), "proto_actions_menu");
+		if (pam)
+			g_free(pam);
+		gtk_container_remove(GTK_CONTAINER(protomenu), GTK_WIDGET(menuitem));
 		l = l->next;
 	}
 
 	while (c) {
 		gc = c->data;
-		if (gc->prpl->actions && gc->prpl->do_action)
+		if (gc->prpl->actions && gc->login_time)
 			count++;
 		c = g_slist_next(c);
 	}
 	c = connections;
 
 	if (!count) {
-		g_snprintf(buf, sizeof(buf), "No actions available");
+		g_snprintf(buf, sizeof(buf), _("No actions available"));
 		menuitem = gtk_menu_item_new_with_label(buf);
-		gtk_menu_append(GTK_MENU(protomenu), menuitem);
+		gtk_menu_shell_append(GTK_MENU_SHELL(protomenu), menuitem);
 		gtk_widget_show(menuitem);
 		return;
 	}
 
 	if (count == 1) {
-		GList *tmp, *act;
+		GList *act;
 		while (c) {
 			gc = c->data;
-			if (gc->prpl->actions && gc->prpl->do_action)
+			if (gc->prpl->actions && gc->login_time)
 				break;
 			c = g_slist_next(c);
 		}
 
-		tmp = act = gc->prpl->actions();
+		act = gc->prpl->actions(gc);
 
 		while (act) {
-			if (act->data == NULL) {
+			if (act->data) {
+				struct proto_actions_menu *pam = act->data;
+				menuitem = gtk_menu_item_new_with_label(pam->label);
+				gtk_menu_shell_append(GTK_MENU_SHELL(protomenu), menuitem);
+				g_signal_connect(GTK_OBJECT(menuitem), "activate",
+							G_CALLBACK(proto_act), pam);
+				g_object_set_data(G_OBJECT(menuitem), "proto_actions_menu", pam);
+				gtk_widget_show(menuitem);
+			} else {
 				gaim_separator(protomenu);
-				act = g_list_next(act);
-				continue;
 			}
-
-			menuitem = gtk_menu_item_new_with_label(act->data);
-			gtk_object_set_user_data(GTK_OBJECT(menuitem), act->data);
-			gtk_menu_append(GTK_MENU(protomenu), menuitem);
-			gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-					   GTK_SIGNAL_FUNC(proto_act), gc);
-			gtk_widget_show(menuitem);
-
 			act = g_list_next(act);
 		}
-
-		g_list_free(tmp);
 	} else {
 		while (c) {
-			GList *tmp, *act;
+			GList *act;
 			gc = c->data;
-			if (!gc->prpl->actions || !gc->prpl->do_action) {
+			if (!gc->prpl->actions || !gc->login_time) {
 				c = g_slist_next(c);
 				continue;
 			}
 
 			g_snprintf(buf, sizeof(buf), "%s (%s)", gc->username, gc->prpl->name);
 			menuitem = gtk_menu_item_new_with_label(buf);
-			gtk_menu_append(GTK_MENU(protomenu), menuitem);
+			gtk_menu_shell_append(GTK_MENU_SHELL(protomenu), menuitem);
 			gtk_widget_show(menuitem);
 
 			submenu = gtk_menu_new();
 			gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem), submenu);
 			gtk_widget_show(submenu);
 
-			tmp = act = gc->prpl->actions();
+			act = gc->prpl->actions(gc);
 
 			while (act) {
-				if (act->data == NULL) {
+				if (act->data) {
+					struct proto_actions_menu *pam = act->data;
+					menuitem = gtk_menu_item_new_with_label(pam->label);
+					gtk_menu_shell_append(GTK_MENU_SHELL(submenu), menuitem);
+					g_signal_connect(GTK_OBJECT(menuitem), "activate",
+								G_CALLBACK(proto_act), pam);
+					g_object_set_data(G_OBJECT(menuitem), "proto_actions_menu",
+							pam);
+					gtk_widget_show(menuitem);
+				} else {
 					gaim_separator(submenu);
-					act = g_list_next(act);
-					continue;
 				}
-
-				menuitem = gtk_menu_item_new_with_label(act->data);
-				gtk_object_set_user_data(GTK_OBJECT(menuitem), act->data);
-				gtk_menu_append(GTK_MENU(submenu), menuitem);
-				gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-						   GTK_SIGNAL_FUNC(proto_act), gc);
-				gtk_widget_show(menuitem);
-
 				act = g_list_next(act);
 			}
-
-			g_list_free(tmp);
 			c = g_slist_next(c);
 		}
 	}
@@ -447,7 +483,7 @@ void connection_has_mail(struct gaim_connection *gc, int count, const char *from
 	struct mail_notify *mn;
 	char buf[2048];
 
-	if (!(gc->user->options & OPT_USR_MAIL_CHECK))
+	if (!(gc->account->options & OPT_ACCT_MAIL_CHECK))
 		return;
 
 	if (!(mn = find_mail_notify(gc))) {
@@ -458,12 +494,12 @@ void connection_has_mail(struct gaim_connection *gc, int count, const char *from
 
 	if (count < 0) {
 		if (from && subject)
-			g_snprintf(buf, sizeof buf, "%s has mail from %s: %s", gc->username, from, subject);
+			g_snprintf(buf, sizeof buf, _("%s has mail from %s: %s"), gc->username, from, *subject ? subject : _("No Subject"));
 		else
-			g_snprintf(buf, sizeof buf, "%s has new mail.", gc->username);
+			g_snprintf(buf, sizeof buf, _("%s has new mail."), gc->username);
 	} else if (count > 0) {
-		g_snprintf(buf, sizeof buf, "%s has %d new message%s.",
-			   gc->username, count, count == 1 ? "" : "s");
+		g_snprintf(buf, sizeof buf, 
+			   ngettext("%s has %d new message.","%s has %d new messages.",count), gc->username, count);
 	} else if (mn->email_win) {
 		gtk_widget_destroy(mn->email_win);
 		return;
@@ -477,10 +513,10 @@ void connection_has_mail(struct gaim_connection *gc, int count, const char *from
 
 
 	GAIM_DIALOG(mn->email_win);
-	gtk_window_set_wmclass(GTK_WINDOW(mn->email_win), "mail", "Gaim");
-	gtk_window_set_policy(GTK_WINDOW(mn->email_win), FALSE, TRUE, TRUE);
+	gtk_window_set_role(GTK_WINDOW(mn->email_win), "mail");
+	gtk_window_set_resizable(GTK_WINDOW(mn->email_win), TRUE);
 	gtk_window_set_title(GTK_WINDOW(mn->email_win), _("Gaim - New Mail"));
-	gtk_signal_connect(GTK_OBJECT(mn->email_win), "destroy", GTK_SIGNAL_FUNC(des_email_win), mn);
+	g_signal_connect(GTK_OBJECT(mn->email_win), "destroy", G_CALLBACK(des_email_win), mn);
 	gtk_widget_realize(mn->email_win);
 
 	vbox = gtk_vbox_new(FALSE, 5);
@@ -498,19 +534,19 @@ void connection_has_mail(struct gaim_connection *gc, int count, const char *from
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-	close = picture_button(mn->email_win, _("Close"), cancel_xpm);
-	gtk_window_set_focus(GTK_WINDOW(mn->email_win), close);
-	gtk_box_pack_end(GTK_BOX(hbox), close, 0, 0, 5);
-	gtk_signal_connect(GTK_OBJECT(close), "clicked", GTK_SIGNAL_FUNC(des_email_win), mn);
-
 	if (url) {
 		mn->url = g_strdup(url);
 		urlbut = picture_button(mn->email_win, _("Open Mail"), tb_forward_xpm);
 		gtk_box_pack_end(GTK_BOX(hbox), urlbut, 0, 0, 5);
-		gtk_signal_connect(GTK_OBJECT(urlbut), "clicked", GTK_SIGNAL_FUNC(open_url), mn->url);
-		gtk_signal_connect(GTK_OBJECT(urlbut), "clicked", GTK_SIGNAL_FUNC(des_email_win), mn);
+		g_signal_connect(GTK_OBJECT(urlbut), "clicked", G_CALLBACK(open_url), mn->url);
+		g_signal_connect(GTK_OBJECT(urlbut), "clicked", G_CALLBACK(des_email_win), mn);
 	}
 
+	close = picture_button(mn->email_win, _("Close"), cancel_xpm);
+	gtk_window_set_focus(GTK_WINDOW(mn->email_win), close);
+	gtk_box_pack_end(GTK_BOX(hbox), close, 0, 0, 5);
+	g_signal_connect(GTK_OBJECT(close), "clicked", G_CALLBACK(des_email_win), mn);
+
 	gtk_widget_show(mn->email_win);
 }
 
@@ -528,18 +564,31 @@ static gint find_icon_data(gconstpointer a, gconstpointer b)
 	const struct icon_data *x = a;
 	const struct icon_data *y = b;
 
-	return ((x->gc != y->gc) || g_strcasecmp(x->who, y->who));
+	return ((x->gc != y->gc) || gaim_utf8_strcasecmp(x->who, y->who));
 }
 
-void set_icon_data(struct gaim_connection *gc, char *who, void *data, int len)
+void set_icon_data(struct gaim_connection *gc, const char *who, void *data, int len)
 {
+	struct gaim_conversation *conv;
 	struct icon_data tmp;
 	GList *l;
 	struct icon_data *id;
+	struct buddy *b;
+	/* i'm going to vent here a little bit about normalize().  normalize()
+	 * uses a static buffer, so when we call functions that use normalize() from
+	 * functions that use normalize(), whose parameters are the result of running
+	 * normalize(), bad things happen.  To prevent some of this, we're going
+	 * to make a copy of what we get from normalize(), so we know nothing else
+	 * touches it, and buddy icons don't go to the wrong person.  Some day I
+	 * will kill normalize(), and dance on its grave.  That will be a very happy
+	 * day for everyone.
+	 *                                    --ndw
+	 */
+	char *realwho = g_strdup(normalize(who));
 	tmp.gc = gc;
-	tmp.who = normalize(who);
+	tmp.who = realwho;
 	tmp.data=NULL;
-        tmp.len = 0;
+	tmp.len = 0;
 	l = g_list_find_custom(icons, &tmp, find_icon_data);
 	id = l ? l->data : NULL;
 
@@ -549,23 +598,72 @@ void set_icon_data(struct gaim_connection *gc, char *who, void *data, int len)
 			icons = g_list_remove(icons, id);
 			g_free(id->who);
 			g_free(id);
+			g_free(realwho);
 			return;
 		}
 	} else if (data) {
 		id = g_new0(struct icon_data, 1);
 		icons = g_list_append(icons, id);
 		id->gc = gc;
-		id->who = g_strdup(normalize(who));
+		id->who = g_strdup(realwho);
 	} else {
+		g_free(realwho);
 		return;
 	}
 
-	debug_printf("Got icon for %s (length %d)\n", who, len);
+	debug_printf("Got icon for %s (length %d)\n", realwho, len);
 
 	id->data = g_memdup(data, len);
 	id->len = len;
 
-	got_new_icon(gc, who);
+	/* Update the buddy icon for this user. */
+	conv = gaim_find_conversation(realwho);
+
+	/* XXX Buddy Icon should probalby be part of struct buddy instead of this weird global
+	 * linked list stuff. */
+
+	if ((b = gaim_find_buddy(gc->account, realwho)) != NULL) {
+		char *random = g_strdup_printf("%x", g_random_int());
+		char *filename = g_build_filename(gaim_user_dir(), "icons", random,
+				NULL);
+		char *dirname = g_build_filename(gaim_user_dir(), "icons", NULL);
+		char *old_icon = gaim_buddy_get_setting(b, "buddy_icon");
+		FILE *file = NULL;
+
+		g_free(random);
+
+		if(!g_file_test(dirname, G_FILE_TEST_IS_DIR)) {
+			debug_printf("creating icon cache directory\n");
+			if(mkdir(dirname, S_IRUSR | S_IWUSR | S_IXUSR) < 0)
+				debug_printf("error creating directory %s: %s\n",
+						dirname, strerror(errno));
+		}
+
+		g_free(dirname);
+
+		file = fopen(filename, "wb");
+		if (file) {
+			fwrite(data, 1, len, file);
+			fclose(file);
+		}
+
+		if(old_icon) {
+			unlink(old_icon);
+			g_free(old_icon);
+		}
+
+		gaim_buddy_set_setting(b, "buddy_icon", filename);
+		gaim_blist_save();
+
+		g_free(filename);
+
+		gaim_blist_update_buddy_icon(b);
+	}
+
+	if (conv != NULL && gaim_conversation_get_gc(conv) == gc)
+		gaim_gtkconv_update_buddy_icon(conv);
+
+	g_free(realwho);
 }
 
 void remove_icon_data(struct gaim_connection *gc)
@@ -585,7 +683,7 @@ void remove_icon_data(struct gaim_connection *gc)
 	}
 }
 
-void *get_icon_data(struct gaim_connection *gc, char *who, int *len)
+void *get_icon_data(struct gaim_connection *gc, const char *who, int *len)
 {
 	struct icon_data tmp = { gc, normalize(who), NULL, 0 };
 	GList *l = g_list_find_custom(icons, &tmp, find_icon_data);
@@ -626,11 +724,13 @@ void show_got_added(struct gaim_connection *gc, const char *id,
 {
 	char buf[BUF_LONG];
 	struct got_add *ga = g_new0(struct got_add, 1);
+	struct buddy *b = gaim_find_buddy(gc->account, who);
 
 	ga->gc = gc;
 	ga->who = g_strdup(who);
 	ga->alias = alias ? g_strdup(alias) : NULL;
 
+
 	g_snprintf(buf, sizeof(buf), _("%s%s%s%s has made %s his or her buddy%s%s%s"),
 		   who,
 		   alias ? " (" : "",
@@ -639,11 +739,11 @@ void show_got_added(struct gaim_connection *gc, const char *id,
 		   id ? id : gc->displayname[0] ? gc->displayname : gc->username,
 		   msg ? ": " : ".",
 		   msg ? msg : "",
-		   find_buddy(gc, ga->who) ? "" : _("\n\nDo you wish to add him or her to your buddy list?"));
-	if (find_buddy(gc, ga->who))
-		do_error_dialog(buf, NULL, GAIM_INFO);
+		   b ? "" : _("\n\nDo you wish to add him or her to your buddy list?"));
+	if (b)
+		do_error_dialog(_("Gaim - Information"), buf, GAIM_INFO);
 	else
-		do_ask_dialog(buf, NULL, ga, _("Add"), do_add, _("Cancel"), dont_add);
+		do_ask_dialog(_("Gaim - Confirm"), buf, ga, _("Add"), do_add, _("Cancel"), dont_add, NULL, FALSE);
 }
 
 static GtkWidget *regdlg = NULL;
@@ -720,9 +820,9 @@ void register_dialog()
 
 	regdlg = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(regdlg), _("Gaim - Registration"));
-	gtk_window_set_wmclass(GTK_WINDOW(regdlg), "register", "Gaim");
+	gtk_window_set_role(GTK_WINDOW(regdlg), "register");
 	gtk_widget_realize(regdlg);
-	gtk_signal_connect(GTK_OBJECT(regdlg), "destroy", GTK_SIGNAL_FUNC(delete_regdlg), NULL);
+	g_signal_connect(GTK_OBJECT(regdlg), "destroy", G_CALLBACK(delete_regdlg), NULL);
 
 	vbox = gtk_vbox_new(FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
@@ -747,7 +847,7 @@ void register_dialog()
 
 	close = picture_button(regdlg, _("Close"), cancel_xpm);
 	gtk_box_pack_end(GTK_BOX(hbox), close, FALSE, FALSE, 5);
-	gtk_signal_connect(GTK_OBJECT(close), "clicked", GTK_SIGNAL_FUNC(delete_regdlg), NULL);
+	g_signal_connect(GTK_OBJECT(close), "clicked", G_CALLBACK(delete_regdlg), NULL);
 	gtk_widget_show(close);
 
 	reg_reg = picture_button(regdlg, _("Register"), ok_xpm);
@@ -760,15 +860,38 @@ void register_dialog()
 	gtk_widget_show(regdlg);
 }
 
-GSList *add_smiley(GSList *list, char *key, char **xpm, int show) 
-{
-	struct _prpl_smiley *smiley;
-
- 	smiley = (struct _prpl_smiley *)g_new0(struct _prpl_smiley, 1);
-	smiley->key = g_strdup(key);
-	smiley->xpm = xpm;
-	smiley->show = show;
-	list = g_slist_append(list, smiley);
-
-	return list;
+static gboolean delayed_unload(void *handle) {
+	g_module_close(handle);
+	return FALSE;
 }
+
+gboolean ref_protocol(struct prpl *p) {
+#ifdef GAIM_PLUGINS
+	if(p->plug) { /* This protocol is a plugin */
+		prpl_accounts[p->protocol]++;
+		debug_printf("Protocol %s now in use by %d connections.\n", p->name, prpl_accounts[p->protocol]);
+		if(!p->plug->handle) { /*But the protocol isn't yet loaded */
+			unload_protocol(p);
+			if (load_prpl(p))
+				return FALSE;
+		}
+	}
+#endif /* GAIM_PLUGINS */
+	return TRUE;
+}
+
+void unref_protocol(struct prpl *p) {
+#ifdef GAIM_PLUGINS
+	if(p->plug) { /* This protocol is a plugin */
+		prpl_accounts[p->protocol]--;
+		debug_printf("Protocol %s now in use by %d connections.\n", p->name, prpl_accounts[p->protocol]);
+		if(prpl_accounts[p->protocol] == 0) { /* No longer needed */
+			debug_printf("Throwing out %s protocol plugin\n", p->name);
+			do_ask_cancel_by_handle(p->plug->handle);
+			g_timeout_add(0, delayed_unload, p->plug->handle);
+			p->plug->handle = NULL;
+		}
+	}
+#endif /* GAIM_PLUGINS */
+}
+
