@@ -32,6 +32,7 @@
 #include "core.h"
 #include "multi.h"
 #include "gtkconv.h"
+#include "pounce.h"
 #include "gtkft.h"
 #include "gtkutils.h"
 #include "stock.h"
@@ -100,103 +101,6 @@ struct window_size {
 	int entry_height;
 };
 
-/* struct buddy_chat went away and got merged with this. */
-#if 0
-struct gaim_conversation {
-	struct gaim_connection *gc;
-
-	/* stuff used for both IM and chat */
-	GtkWidget *window;
-	char name[80];
-	GtkWidget *toolbar;
-	GtkWidget *text;
-/*	GtkWidget *entry; */
-	GtkWidget *italic;
-	GtkWidget *bold;
-	GtkWidget *underline;
-	GtkWidget *fgcolorbtn;
-	GtkWidget *bgcolorbtn;
-	GtkWidget *link;
-/*	GtkWidget *sendfile_btn; */
-	GtkWidget *wood;
-	GtkWidget *viewer_button;
-	GtkWidget *log_button;
-	GtkWidget *strike;
-	GtkWidget *font;
-	GtkWidget *smiley;
-	GtkWidget *imagebtn;
-	GtkWidget *image_menubtn;
-	GtkWidget *speaker;
-	GtkWidget *speaker_p;
-	GtkWidget *fg_color_dialog;
-	GtkWidget *bg_color_dialog;
-	GtkWidget *font_dialog;
-	GtkWidget *smiley_dialog;
-	GtkWidget *link_dialog;
-	GtkWidget *log_dialog;
-	GtkSizeGroup *sg;
-	int makesound;
-	char fontface[128];
-	int hasfont;
-	GdkColor bgcol;
-	int hasbg;
-	GdkColor fgcol;
-	int hasfg;
-
-	GList *send_history;
-	GString *history;
-
-	GtkWidget *send;
-
-	/* stuff used just for IM */
-	GtkWidget *lbox;
-	GtkWidget *bbox;
-	GtkWidget *sw;
-	GtkWidget *info;
-	GtkWidget *warn;
-	GtkWidget *block;
-	GtkWidget *add;
-	GtkWidget *sep1;
-	GtkWidget *sep2;
-	GtkWidget *menu;
-	GtkWidget *check;
-	GtkWidget *progress;
-	GSList    *images;  /* A list of filenames to embed */
-	gint unseen;
-	int typing_state;
-	guint typing_timeout;
-	time_t type_again;
-	guint type_again_timeout;
-
-	/* stuff used just for chat */
-        GList *in_room;
-        GList *ignored;
-	char *topic;
-        int id;
-	GtkWidget *count;
-	GtkWidget *list;
-	GtkWidget *whisper; 
-	GtkWidget *invite;
-	GtkWidget *close; 
-	GtkWidget *topic_text;
-
-	/* something to distinguish */
-	gboolean is_chat;
-
-	/* buddy icon stuff. sigh. */
-	GtkWidget *icon;
-	GdkPixbufAnimation *anim;
-	guint32 icon_timer;
-	GdkPixbufAnimationIter *iter;
-	GtkWidget *save_icon;
-
-	GtkTextBuffer *entry_buffer;
-	GtkWidget     *entry;
-
-	GtkWidget *tab_label;
-};
-#endif
-
 struct log_conversation {
 	char name[80];
 	char filename[512];
@@ -211,23 +115,6 @@ struct away_message {
 	char message[2048];
 };
 
-/****************************
- * I thought I'd place these here by the same reasoning used above (for away_message)
- * This helps aleviate warnings from dialogs.c where the show_new_bp function references
- * buddy_pounce in the parameter list when ui.h doesn't know about buddy_pounce
- * **************************
- */
-struct buddy_pounce {
-        char name[80];
-        char message[2048];
-        char command[2048];
-        char sound[2048];
-        
-        char pouncer[80];
-        int protocol;
-
-        int options;
-};
 
 
 /* this is used for queuing messages received while away. This is really a UI function
@@ -261,6 +148,7 @@ struct smiley_theme {
 extern GList *log_conversations; /* this should be moved to conversations.c */
 extern GSList *away_messages; /* this should be moved to away.c */
 extern GtkWidget *mainwindow;
+extern int docklet_count;
 
 /* Globals in away.c */
 extern struct away_message *awaymessage;
@@ -270,24 +158,6 @@ extern GtkWidget *awaymenu;
 extern GtkWidget *awayqueue;
 extern GtkListStore *awayqueuestore;
 
-/* Globals in buddy.c */
-extern GtkWidget *buddies;
-extern GtkWidget *bpmenu;
-extern GtkWidget *blist;
-extern int docklet_count;
-
-/* Globals in buddy_chat.c */
-#if 0
-extern GList *chats;	/* list of all chats (only use for tabbing!) */
-extern GtkWidget *all_chats;
-extern GtkWidget *joinchat;
-#endif
-
-/* Globals in conversation.c */
-#if 0
-extern GtkWidget *all_convos;
-#endif
-
 /* Globals in dialog.c */
 extern char fontface[128];
 extern char fontxfld[256];
@@ -298,6 +168,9 @@ extern int smiley_array[FACE_TOTAL];
 extern GtkWidget *fgcseld;
 extern GtkWidget *bgcseld;
 
+/* Globals in pounce.c */
+extern GtkWidget *bpmenu;
+
 /* Globals in prefs.c */
 extern GtkWidget *prefs;
 extern struct debug_window *dw;
@@ -367,56 +240,6 @@ extern void update_idle_times();
 extern void build_imchat_box(gboolean);
 extern void show_xfer_dialog();
 
-/* Functions in buddy_chat.c */
-#if 0
-extern void chat_write(struct gaim_conversation *, char *, int, char *, time_t);
-extern void delete_chat(struct gaim_conversation *);
-extern void update_chat_button_pix();
-extern void update_im_button_pix();
-extern void update_chat_tabs();
-extern void update_im_tabs();
-extern void do_join_chat();
-#endif
-
-/* Functions in conversation.c */
-#if 0
-extern void update_convo_add_button(struct gaim_conversation *);
-extern void raise_convo_tab(struct gaim_conversation *);
-extern void set_convo_title(struct gaim_conversation *);
-extern void show_conv(struct gaim_conversation *);
-void set_convo_name(struct gaim_conversation *c, const char *nname);
-extern struct gaim_conversation *new_conversation(char *);
-extern void delete_conversation(struct gaim_conversation *);
-extern void surround(struct gaim_conversation *, char *, char *);
-extern int is_logging(char *);
-extern void set_state_lock(int);
-extern void remove_tags(struct gaim_conversation *, char *);
-extern void update_transparency();
-extern void update_font_buttons();
-extern void set_font_face(char *, struct gaim_conversation *);
-extern void redo_convo_menus();
-extern void convo_menu_remove(struct gaim_connection *);
-extern void remove_icon_data(struct gaim_connection *);
-extern void got_new_icon(struct gaim_connection *, char *);
-extern void toggle_spellchk();
-extern void set_convo_gc(struct gaim_conversation *, struct gaim_connection *);
-extern void update_buttons_by_protocol(struct gaim_conversation *);
-extern void toggle_fg_color(GtkWidget *, struct gaim_conversation *);
-extern void toggle_smileys();
-extern void toggle_timestamps();
-extern void update_pixmaps();
-extern void im_tabize();
-extern void chat_tabize();
-extern void convo_tabize();
-extern void update_convo_color();
-extern void update_convo_font();
-extern void set_hide_icons();
-extern void set_convo_titles();
-extern void update_progress(struct gaim_conversation *, float);
-extern void update_convo_status(struct gaim_conversation *);
-extern void set_anim();
-#endif
-
 /* Functions in dialogs.c */
 extern void alias_dialog_bud(struct buddy *);
 extern void show_warn_dialog(struct gaim_connection *, char *);
@@ -480,6 +303,7 @@ extern void update_show_plugins(); /* this is a hack and will be removed */
 extern void set_option(GtkWidget *, int *);
 extern void show_prefs();
 extern void show_debug();
+extern void toggle_debug();
 extern void update_color(GtkWidget *, GtkWidget *);
 extern void set_default_away(GtkWidget *, gpointer);
 extern void default_away_menu_init(GtkWidget *);
@@ -508,7 +332,8 @@ extern void session_end();
 /* Functions in themes.c */
 extern void smiley_themeize(GtkWidget *);
 extern void smiley_theme_probe();
-extern struct smiley_theme *load_smiley_theme(const char *file, gboolean load);
+extern void load_smiley_theme(const char *file, gboolean load);
+extern GSList *get_proto_smileys(int protocol);
 
 /* Fucnctions in util.c */
 extern GtkWidget *gaim_pixmap(char *, char *);
